@@ -6,21 +6,33 @@ add_java_DFS_support <- function(henv){
     if( !all(hadoop_get_jars(henv) %in% .jclassPath()) ){
         .jaddClassPath( hadoop_get_jars(henv) )
     }
-  ## add paths to Hadoop configuration files
-  core_default <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "src", "core", "core-default.xml"))
-  core_site <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "conf", "core-site.xml"))
-  hdfs_default <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "src", "hdfs", "hdfs-default.xml"))
-  hdfs_site <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "conf", "hdfs-site.xml"))
-  mapred_default <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "src", "mapred", "mapred-default.xml"))
-  mapred_site <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "conf", "mapred-site.xml"))
-
-  configuration <- .jnew("org/apache/hadoop/conf/Configuration")
-  .jcall(configuration, "V", "addResource", core_default)
-  .jcall(configuration, "V", "addResource", core_site)
-  .jcall(configuration, "V", "addResource", hdfs_default)
-  .jcall(configuration, "V", "addResource", hdfs_site)
-  .jcall(configuration, "V", "addResource", mapred_default)
-  .jcall(configuration, "V", "addResource", mapred_site)
+    if( hadoop_version(henv) >= "2.6.0" ){
+        hadoop_src <- file.path(hadoop_home(henv), "share", "doc", "hadoop")
+        hadoop_lib <- file.path(hadoop_home(henv), "share", "hadoop", "common", "lib")
+        hadoop_mapreduce <- file.path(hadoop_home(henv), "share", "hadoop", "mapreduce")
+        core_default <- .jnew( "org/apache/hadoop/fs/Path", file.path(hadoop_src, "hadoop-project-dist", "hadoop-common", "core-default.xml") )
+        core_site    <- .jnew( "org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "etc", "hadoop", "core-site.xml") )
+        hdfs_default <- .jnew( "org/apache/hadoop/fs/Path", file.path(hadoop_src, "hadoop-project-dist", "hadoop-hdfs", "hdfs-default.xml"))
+        hdfs_site    <- .jnew( "org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "etc", "hadoop", "hdfs-site.xml"))
+        mapred_default <- .jnew( "org/apache/hadoop/fs/Path", file.path(hadoop_src, "hadoop-mapreduce-client", "hadoop-mapreduce-client-core", "mapred-default.xml") )
+        mapred_site  <- .jnew( "org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "etc", "hadoop", "mapred-site.xml"))
+    } else {
+        ## add paths to Hadoop configuration files
+        core_default <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "src", "core", "core-default.xml"))
+        core_site <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "conf", "core-site.xml"))
+        hdfs_default <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "src", "hdfs", "hdfs-default.xml"))
+        hdfs_site <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "conf", "hdfs-site.xml"))
+        mapred_default <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "src", "mapred", "mapred-default.xml"))
+        mapred_site <- .jnew("org/apache/hadoop/fs/Path", file.path(hadoop_home(henv), "conf", "mapred-site.xml"))
+    }
+    configuration <- .jnew("org/apache/hadoop/conf/Configuration")
+    .jcall(configuration, "V", "addResource", core_default)
+    .jcall(configuration, "V", "addResource", core_site)
+    .jcall(configuration, "V", "addResource", hdfs_default)
+    .jcall(configuration, "V", "addResource", hdfs_site)
+    .jcall(configuration, "V", "addResource", mapred_default)
+    .jcall(configuration, "V", "addResource", mapred_site)
+    
 
   ## Update class loader
   jcl <- .jclassLoader()
